#
# spec file for package python-pytest-xvfb
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pytest-xvfb
Version:        3.0.0
Release:        1.7
Summary:        Pytest plugin to run Xvfb for tests
License:        MIT
URL:            https://github.com/The-Compiler/pytest-xvfb
Source:         https://files.pythonhosted.org/packages/source/p/pytest-xvfb/pytest-xvfb-%{version}.tar.gz
BuildRequires:  %{python_module PyVirtualDisplay >= 1.3}
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest >= 2.8.1}
BuildRequires:  %{python_module setuptools >= 61.2}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  xvfb-run
Requires:       python-PyVirtualDisplay >= 1.3
Requires:       python-pytest >= 2.8.1
Requires:       xdpyinfo
Recommends:     xorg-x11-server
BuildArch:      noarch
%python_subpackages

%description
A pytest plugin to run Xvfb for tests.

With Xvfb and the plugin installed, your testsuite automatically runs
with Xvfb. This allows tests to be run without windows popping up
during GUI tests or on systems without a display (like a CI).

If Xvfb is not installed, the plugin does not run and your tests will
still work as normal. However, a warning message will print to standard
output letting you know that Xvfb is not installed.

If you're currently using xvfb-run in something like .travis.yml,
simply remove it and install this plugin instead - then you'll also have the
benefits of Xvfb locally.

%prep
%setup -q -n pytest-xvfb-%{version}
rm tests/test_xvfb_windows.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# can't test this on obs
donttest="test_empty_display or test_no_xvfb_marker or test_xvfb_with_xauth"
%pytest -k "not ($donttest)"

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/pytest_xvfb.py
%pycache_only %{python_sitelib}/__pycache__/pytest_xvfb*.pyc
%{python_sitelib}/pytest_xvfb-%{version}.dist-info

%changelog
* Wed Sep 27 2023 Ben Greiner <code@bnavigator.de>
- Update to 3.0.0
  * New --xvfb-backend argument, which can be used to run Xephyr or
    Xvnc in place of Xvfb (e.g. for visual inspection but on a
    remote system or a consistent screen size needed).
  * Support for Python 3.5 and 3.6 is now dropped, while official
    support for 3.9, 3.10 and 3.11 was added (with no code chances
    required).
  * The Xvfb instance is now no longer saved in pytest's config
    object as config.xvfb anymore, and only available via the xvfb
    fixture.
  * Xvfb is now shut down as late as possible (via an atexit hook
    registered at import time), seemingly avoiding errors such as
    "XIO: fatal IO error 0 (Success)".
  * Code reformatting using black/shed.
  * Packaging refresh using pyproject.toml.
* Sat Jun 10 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Wed Oct  6 2021 Axel Braun <axel.braun@gmx.de>
- skip python2 to make it build for Leap 15.3
* Thu Aug 20 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v2.0.0:
  * PyVirtualDisplay 1.3 and newer is now supported, support for older versions was dropped.
  * Support for Python 2.7, 3.3 and 3.4 is now dropped.
  * Support for Python 3.6, 3.7 and 3.8 was added (no code changes required).
  * Xvfb is now not started anymore in the xdist master process.
* Sun May 24 2020 Tomáš Chvátal <tchvatal@suse.com>
- Require also xdpyinfo as it is used for verifications
* Tue Apr 23 2019 Tomáš Chvátal <tchvatal@suse.com>
- Skip one of the tests checking for error return code that fails
  on i586
* Tue Feb 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.2.0:
  * Item.get_closest_marker is now used, which restores compatibility with pytest 4.1.0 and requires pytest 3.6.0 or newer.
* Tue Feb 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Really run tests
- Remove devel dependency
* Sun Apr 15 2018 arun@gmx.de
- specfile:
  * update copyright year
  * always run tests
- update to version 1.1.0:
  * The xvfb_args option is now a single line parsed with shlex.split.
  * The XvfbExitedError exception now includes stdout and stderr.
* Mon Aug 28 2017 toddrme2178@gmail.com
- Initial version
